@@ -7,7 +7,7 @@ class NsjInjectorFactoryBase:
     _db_connection: Connection
 
     def __enter__(self):
-        from nsj_rest_lib.db_pool_config import internal_db_pool
+        from nsj_rest_lib.db_pool_config import db_pool as internal_db_pool
 
         pool = internal_db_pool
         if db_pool is not None:
